Minnesota Court of Appeals Published Opinions

Minnesota Court of Appeals
October - December 2015
Published Opinions

#### October 13, 2015

- A13-931, State of Minnesota, Respondent, vs. Todd Eugene Trahan, Appellant.
- A15-116, Builders Association of the Twin Cities, Petitioner, vs. Minnesota Department of Labor and Industry, Respondent.

#### October 5, 2015

- NO PUBLISHED OPINIONS FILED

  MSLL Home Page | | Minnesota Appellate Court System | | Archive Homepage

  Phone: (651) 296-2775; Fax: (651) 296-6740

  This site is continually being updated and we welcome your input.
  Please send any comments or suggestions to the Webweaver.

  Last update: October 5, 2015